@@ -24,10 +24,28 @@
 #ifndef GIRL_H
 #define GIRL_H
 
+typedef enum {
+	GIRL_CHANNELS_MONO = 0x0001,
+	GIRL_CHANNELS_STEREO = 0x0002,
+	GIRL_CHANNELS_5_1 = 0x0005,
+	GIRL_CHANNELS_NONE = 0xffff
+} GirlChannels;
+
+typedef enum {
+	GIRL_STREAM_SHOUTCAST = 0x0001,
+	GIRL_STREAM_OGG = 0x0002
+} GirlStreamType;
+
+typedef enum {
+	GIRL_STREAM_PLAYER = 0x0001,
+	GIRL_STREAM_RECORD = 0x0002
+} GirlHelperType;
+
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include "girl-station.h"
 #include "girl-listener.h"
+#include "girl-program.h"
+#include "girl-station.h"
 
 #ifdef DEBUG
 #define MSG(x...) g_message(x)
@@ -46,20 +64,23 @@ gchar *copy_to_mem(GnomeVFSURI * uri, GnomeVFSFileSize len);
 
 /* Fetcher for the stations */
 
-void girl_launch_helper(char *url, GirlStreamType type);
+void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType girl);
 void on_listen_button_clicked(GtkWidget * button, gpointer user_data);
+void on_record_button_clicked(GtkWidget * button, gpointer user_data);
 void on_next_click(GtkWidget *, gpointer user_data);
 void on_previous_click(GtkWidget *, gpointer user_data);
 void on_listeners_selector_button_clicked(GtkWidget *, gpointer user_data);
 void on_listeners_selector_changed(GtkWidget * a, gpointer user_data);
+void on_programs_selector_button_clicked(GtkWidget *, gpointer user_data);
+void on_programs_selector_changed(GtkWidget * a, gpointer user_data);
 void on_stations_selector_button_clicked(GtkWidget *, gpointer user_data);
 void on_stations_selector_changed(GtkWidget * a, gpointer user_data);
 void quit_app(GtkWidget *, gpointer user_data);
 void about_app(GtkWidget *, gpointer user_data);
 void about_listener(GtkWidget *, gpointer user_data);
+void about_program(GtkWidget *, gpointer user_data);
 void about_station(GtkWidget *, gpointer user_data);
 
-
 struct _GirlData {
 	GtkImage *pixmap;
 	GnomeAppBar *appbar;
@@ -69,6 +90,12 @@ struct _GirlData {
 	gchar *selected_listener_location;
 	gchar *selected_listener_release;
 	gchar *selected_listener_description;
+	GirlProgramInfo *selected_program;
+	gchar *selected_program_uri;
+	gchar *selected_program_name;
+	gchar *selected_program_location;
+	gchar *selected_program_release;
+	gchar *selected_program_description;
 	GirlStationInfo *selected_station;
 	gchar *selected_station_uri;
 	gchar *selected_station_name;
@@ -85,6 +112,7 @@ typedef struct _GirlData GirlData;
 
 extern GirlData *girl;
 extern GList *girl_stations;
+extern GList *girl_programs;
 extern GList *girl_listeners;
 
 #endif /* GIRL_H */
